# -*- coding: utf-8 -*-
"""
dictionary.py - translate or edit the dictionary.

Parts by Yaacov Zamir.

Copyright (C) 2005 Nir Soffer <nirs@freeshell.org>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
"""

import urllib
import webbrowser

translateURL = 'http://www.jlc.org.il/limon/limon.php?term=%s&type=%s'
newURL = 'http://www.jlc.org.il/limon/edit-limon.php?newterm=%s'
editURL = 'http://www.jlc.org.il/limon/limon.php?term=%s&type=web'

class Error(Exception):
    """ Raised for limon errors """


def _getEntries(term, type):
    """ Parse the wired format returned by limon.php 
    
    item| item| item| \n\n
    """
    try:
        entries = urllib.urlopen(translateURL % (term, type)).read()
    except IOError, err:
        raise Error(err)    
    entries = entries.strip()
    if not entries:
        return []
    entries = entries.rstrip('|')
    return [item.strip() for item in entries.split('| ')]


def define(word):
    """ Define word using http://www.jlc.org.il/limon 
    
    word should be string using utf-8 encoding.
    
    Return list of translations. Each translation is a dict with 'he',
    'en' and 'meaning' keys. Values are utf-8 strings.
    
    TODO: use one request to get all the information
    TODO: add the id for each definition [{id, heb, eng, meaning}...]
    """
    term = urllib.quote(word)
    en = _getEntries(term, 'eng')
    he = _getEntries(term, 'heb')
    meaning = _getEntries(term, 'heb-exp')    
    result = []
    for i in range(len(en)):
        result.append({'en': en[i], 'he': he[i], 'meaning': meaning[i]})
    return result        
    

def new(word):
    """ Open a browser with an editor for new word """
    try:
        webbrowser.open(newURL % urllib.quote(word))
    except webbrowser.Error, err:
        raise Error(err)

def edit(word):
    """ Open a browser with the editor for exiting word """
    try:
        webbrowser.open(editURL % urllib.quote(word))
    except webbrowser.Error, err:
        raise Error(err)
